// 633_COMMAND_LINE_TEST.cpp
// Ultra-simple 633 command-line communications example

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>
#include "serial.h"
#include "633_packet.h"
#include "show_packet.h"
#include <string>
#include <fstream>
#include <iostream>
#include <termios.h>

using namespace std;

void   init_keyboard(void);
void   close_keyboard(void);
int    kbhit(void);
int    readch(void);

static struct termios initial_settings, new_settings;
static int peek_character = -1;

void init_keyboard()
{
    tcgetattr(0,&initial_settings);
    new_settings = initial_settings;
    new_settings.c_lflag &= ~ICANON;
    new_settings.c_lflag &= ~ECHO;
    new_settings.c_lflag &= ~ISIG;
    new_settings.c_cc[VMIN] = 1;
    new_settings.c_cc[VTIME] = 0;
    tcsetattr(0, TCSANOW, &new_settings);
}

void close_keyboard()
{
    tcsetattr(0, TCSANOW, &initial_settings);
}

int kbhit()
{
unsigned char ch;
int nread;

    if (peek_character != -1) return 1;
    new_settings.c_cc[VMIN]=0;
    tcsetattr(0, TCSANOW, &new_settings);
    nread = read(0,&ch,1);
    new_settings.c_cc[VMIN]=1;
    tcsetattr(0, TCSANOW, &new_settings);
    if(nread == 1)
    {
        peek_character = ch;
        return 1;
    }
    return 0;
}

int readch()
{
char ch;

    if(peek_character != -1)
    {
        ch = peek_character;
        peek_character = -1;
        return ch;
    }
    read(0,&ch,1);
    return ch;
}
//============================================================================
int main(int argc, char* argv[])
  {

	if(argc!=5)
	{
		printf("Ultra-simple CFA-631 / CFA-633 / CFA-635 command-line communications example.\n");
		printf("Crystalfontz America, Inc. http://www.crystalfontz.com\n\n");
		printf("Usage:\n");
		printf("  %s port speed poll_delay text_file\n\n",argv[0]);
		printf("    \"port\"   COM1, COM2 . . .\n");
		printf("    \"baud\"   1200,2400,4800,9600 or 19200\n");
		printf("    \"poll_delay\" time between updates, in mS\n");
		printf("    \"text_file\" first 16 characters of the first\n");
		printf("                first 2 lines are sent to the display\n\n");
		exit(1);
	}
  int baud;
  //default the baud to 19200
  if(strcmp(argv[2],"115200"))
    baud=19200;
  else
    baud=115200;

   string port = argv[1];

    if(Serial_Init((char*)port.c_str(),baud))
    {
    printf("Could not open port \"%s\" at \"%d\" baud.\n",argv[1],baud);

    while(!kbhit())
	usleep(1);
    while(kbhit())
       readch();
    	exit(6);
    }
  else
    printf("\"%s\" opened at \"%d\" baud.\n\n",argv[1],baud);


 	fstream textFile;		//fstream variable for access to the text file

	textFile.open(argv[4]);

	if(!textFile.is_open())
	{
		//if it's not, exit
		exit(1);
	}

	
	long poll_delay;
	poll_delay=atol(argv[3]);
	if((poll_delay<50)||(60000<poll_delay))
	{
		printf("\"poll_delay\" must be in the range of 50 (20 updates per second)\nto 60000 (1 update per minute)\n\2n");
		exit(1);
	}

	//See if we can get the input file open
	// verify that the configuration file is open.

	for(int line=0;line<=1;line++)
	{
		string this_line;
		getline(textFile,this_line,'\n');
		int charPos=0;

		for(int i=0;i<18;i++)
		{
			if(this_line[i]!='\0')
			{
				this_line[charPos]=this_line[i];
				charPos++;
			}
			else if(i<=18)
			{
				while(i<=18)
				{
					this_line[i-1]=' ';
					i++;
				}
			}
			if(i>=18)
				break;
		}
		outgoing_response.command=31;
		outgoing_response.data_length=18;
		outgoing_response.data[0]=0;
		outgoing_response.data[1]=line;
		memcpy(&outgoing_response.data[2],this_line.c_str(),16);
		send_packet();
	}
	//Tidy up by closing the file
	textFile.close();
	//Fail to burn up all the CPU cycles
	usleep(poll_delay*100);
  printf("Updated display\n\n");

  Uninit_Serial();
  return 0;
  }
//============================================================================
